@@ -88,6 +88,15 @@ class FacebookScraper:
             post = {"original_request_url": post_url, "post_url": url}
             logger.debug(f"Requesting page from: {url}")
             response = self.get(url)
+            if response.url == "https://m.facebook.com/watch/?ref=watch_permalink":
+                if str(post_url).isdigit():
+                    url = utils.urljoin(
+                        FB_MOBILE_BASE_URL,
+                        f"story.php?story_fbid={post_url}&id=1&m_entstream_source=timeline",
+                    )
+                    post = {"original_request_url": post_url, "post_url": url}
+                    logger.debug(f"Requesting page from: {url}")
+                    response = self.get(url)
             if "/watch/" in response.url:
                 video_id = parse_qs(urlparse(response.url).query).get("v")[0]
                 url = f"story.php?story_fbid={video_id}&id={video_id}&m_entstream_source=video_home&player_suborigin=entry_point&player_format=permalink"
@@ -154,18 +163,30 @@ class FacebookScraper:
         while friend_url:
             logger.debug(f"Requesting page from: {friend_url}")
             response = self.get(friend_url)
-            elems = response.html.find('div[data-sigil="undoable-action"]')
+            elems = response.html.find('div[class="timeline"] > div > div')
             logger.debug(f"Found {len(elems)} friends")
             for elem in elems:
-                name = elem.find("h3>a", first=True)
-                tagline = elem.find("div.notice.ellipsis", first=True).text
+                name = elem.find("h3>a,h1>a", first=True)
+                if not name:
+                    continue
+                # Tagline
+                tagline = elem.find("span.fcg", first=True)
+                if tagline:
+                    tagline = tagline.text
+                else:
+                    tagline = ""
+                # Profile Picture
                 profile_picture = elem.find("i.profpic", first=True).attrs.get("style")
                 match = re.search(r"url\('(.+)'\)", profile_picture)
                 if match:
                     profile_picture = utils.decode_css_url(match.groups()[0])
-                user_id = json.loads(
-                    elem.find("a.touchable[data-store]", first=True).attrs["data-store"]
-                ).get("id")
+                # User ID if present, not present if no "add friend"
+                user_id = elem.find("a.touchable[data-store]", first=True)
+                if user_id:
+                    user_id = json.loads(user_id.attrs["data-store"]).get("id")
+                else:
+                    user_id = ""
+
                 friend = {
                     "id": user_id,
                     "link": name.attrs.get("href"),
@@ -251,7 +272,7 @@ class FacebookScraper:
 
             try:
                 result["Friend_count"] = utils.parse_int(
-                    response.html.find("a[data-store*='friends']>div>div")[-1].text
+                    response.html.find("a[data-store*='friends']>div>div")[-1].text.split()[0]
                 )
             except Exception as e:
                 result["Friend_count"] = None
@@ -376,7 +397,15 @@ class FacebookScraper:
                 elif len(bits) == 1:
                     result[header] = bits[0]
                 elif (
-                    header in ["Contact Info", "Basic Info", "Education", "Family Members", "Other names"] and len(bits) % 2 == 0
+                    header
+                    in [
+                        "Contact Info",
+                        "Basic Info",
+                        "Education",
+                        "Family Members",
+                        "Other names",
+                    ]
+                    and len(bits) % 2 == 0
                 ):  # Divisible by two, assume pairs
                     pairs = {}
                     for i in range(0, len(bits), 2):
@@ -625,7 +654,7 @@ class FacebookScraper:
         elems = response.html.find("input[name][value]")
         data = {elem.attrs['name']: elem.attrs['value'] for elem in elems}
         data.update(extra_data)
-        response = self.session.post(url, data=data)
+        response = self.session.post(url, data=data, **self.requests_kwargs)
         return response
 
     def login(self, email: str, password: str):
